@@ -52,7 +52,7 @@ setMethod('click', signature(x='SpatialGrid'),
 		r <- raster(x)
 		cells <- .getCellFromClick(r, n, type, id, ...)
 		
-		if (methods::.hasSlot(x, 'data')) {
+		if (.hasSlot(x, 'data')) {
 			value <- x@data[cells, ,drop=FALSE]
 		} else {
 			value <- NULL
@@ -74,7 +74,7 @@ setMethod('click', signature(x='SpatialPixels'),
 		r <- raster(x)
 		cells <- .getCellFromClick(r, n, type, id, ...)
 		
-		if (methods::.hasSlot(x, 'data')) {
+		if (.hasSlot(x, 'data')) {
 			value <- x@data[cells, ,drop=FALSE]
 		} else {
 			value <- NULL
@@ -122,6 +122,7 @@ setMethod('click', signature(x='Raster'),
 	while (i < n) {
 		i <- i + 1
 		loc <- graphics::locator(1, type, ...)
+		if (is.null(loc)) break
 		xyCoords <- cbind(x=loc$x, y=loc$y)
 		if (id) { 
 			text(xyCoords, labels=i) 
@@ -171,7 +172,7 @@ setMethod('click', signature(x='SpatialPolygons'),
 		xyCoords@proj4string <- x@proj4string
 		i <- which(!is.na(over(x, xyCoords)))
 		if (length(i) > 0) {
-			if (methods::.hasSlot(x, 'data')) {
+			if (.hasSlot(x, 'data')) {
 				x <- x@data[i,]
 			} else {
 				x <- row.names(x)[i]
@@ -194,7 +195,7 @@ setMethod('click', signature(x='SpatialLines'),
 		e@proj4string <- x@proj4string
 		i <- which(!is.na(over(x, e)))
 		if (length(i) > 0) {
-			if (methods::.hasSlot(x, 'data')) {
+			if (.hasSlot(x, 'data')) {
 				x <- x@data[i,]
 			} else {
 				x <- row.names(x)[i]
@@ -212,7 +213,7 @@ setMethod('click', signature(x='SpatialPoints'),
 		e@proj4string <- x@proj4string
 		i <- which(!is.na(over(x, e)))
 		if (length(i) > 0) {
-			if (methods::.hasSlot(x, 'data')) {
+			if (.hasSlot(x, 'data')) {
 				x <- x@data[i,]
 			} else {
 				x <- row.names(x)[i]
