@@ -95,7 +95,7 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 		} else {
 			y <- 0
 		}
-		v <- .Call('terrain', as.double(values(x)), as.integer(dim(out)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
+		v <- .terrain(as.double(values(x)), as.integer(dim(out)), rs, un, nopt, lonlat, y)
 		out <- setValues(out, v)
 		if (filename  != '') {
 			out <- writeRaster(out, filename, ...)
@@ -112,13 +112,13 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 		v <- getValues(x, row=1, nrows=tr$nrows[1]+1)
 		y <- 0
 		if (lonlat) { y <- yFromRow(out, 1:(tr$nrows[1]+1)) }
-		v <- .Call('terrain', as.double(v), as.integer(c(tr$nrows[1]+1, nc)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
+		v <- .terrain(as.double(v), as.integer(c(tr$nrows[1]+1, nc)), rs, un, nopt, lonlat, y)
 		out <- writeValues(out, matrix(v, ncol=nl), 1)
 		pbStep(pb, 1)
 		for (i in 2:(tr$n-1)) {
 			v <- getValues(x, row=tr$row[i]-1, nrows=tr$nrows[i]+2)
 			if (lonlat) { y <- yFromRow(out, (tr$row[i]-1) : (tr$row[i]+tr$nrows[i])) }
-			v <- .Call('terrain', as.double(v), as.integer(c(tr$nrows[i]+2, nc)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
+			v <- .terrain(as.double(v), as.integer(c(tr$nrows[i]+2, nc)), rs, un, nopt, lonlat, y)
 			v <- matrix(v, ncol=nl)[-buf,]
 			out <- writeValues(out, v, tr$row[i])
 			pbStep(pb, i)		
@@ -126,7 +126,7 @@ terrain <- function(x, opt='slope', unit='radians', neighbors=8, filename='', ..
 		i <- tr$n
 		v <- getValues(x, row=tr$row[i]-1, nrows=tr$nrows[i]+1)
 		if (lonlat) { y <- yFromRow(out, (tr$row[i]-1) : (tr$row[i]+tr$nrows[i]-1)) }
-		v <- .Call('terrain', as.double(v), as.integer(c(tr$nrows[i]+1, nc)), rs, un, nopt, lonlat, y, NAOK=TRUE, PACKAGE='raster')
+		v <- .terrain(as.double(v), as.integer(c(tr$nrows[i]+1, nc)), rs, un, nopt, lonlat, y)
 		v <- matrix(v, ncol=nl)[-buf,]
 		out <- writeValues(out, v, tr$row[i])
 		pbStep(pb, tr$n)
